---
title: <span class="badge builder"></span> ElasticsearchExtendedStatsSettings
---
# <span class="badge builder"></span> ElasticsearchExtendedStatsSettings

## Constructor

```python
ElasticsearchExtendedStatsSettings()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> elasticsearch.ElasticsearchExtendedStatsSettings
```

### <span class="badge object-method"></span> missing

```python
def missing(missing: str) -> typing.Self
```

### <span class="badge object-method"></span> script

```python
def script(script: cogbuilder.Builder[elasticsearch.InlineScript]) -> typing.Self
```

### <span class="badge object-method"></span> sigma

```python
def sigma(sigma: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [ElasticsearchExtendedStatsSettings](./object-ElasticsearchExtendedStatsSettings.md)
